////////////////////////////////////////////////////////////////////////////////
/// @file
/// @brief 文字コード変換関数のソース
///
/// 文字コードの変換を行います。
/// 入力はSJIS、出力はUTF-8が前提になっています。
///
/// Copyright (C) 2009 Alpha Systems Inc. All Rights Reserved.
/// @internal
/// @date $Date: $
/// @version $Revision: $
////////////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <memory.h>
#include <string.h>
#include <iconv.h>

/// @brief 文字コードの変換(SJIS -> UTF-8)
/// @param src 変換元文字列
/// @param[out] dst 変換後の文字列
/// @param strSrcLen 変換元文字列の長さ
/// @param strDstLen 変換後の文字列の長さ
/// @retval 0 正常終了
/// @retval -1 異常終了
/// @author hattay

int convertCharset(const char *src, char **dst, size_t strSrcLen, size_t strDstLen)
{
	if(src == NULL)
	{
		return -1;
	}
	if(dst == NULL)
	{
		return -1;
	}
	if(*(dst) == NULL)
	{
		return -1;
	}
	if(strSrcLen <= 0)
	{
		return -1;
	}
	if(strDstLen <= 0)
	{
		return -1;
	}

	iconv_t cd;
	int resultConvert = 0;

	cd = iconv_open("UTF-8", "SJIS");
	if(cd == (iconv_t)-1)
	{
		return -1;
	}

	resultConvert = iconv(cd, &src, &strSrcLen, dst, &strDstLen);
	iconv_close(cd);

	if(resultConvert < 0)
	{
		printf("%d\n", errno);
		return -1;
	}

	return 0;
}
